==> fastapi_tags-0.2.1.tar.gz: fastapi_tags-0.2.1/tests/test_tags.py <==
import fastapi_tags as ft


def test_atag_no_attrs_no_children():
    assert ft.A().render() == "<a></a>"


def test_atag_yes_attrs_no_children():
    tag = ft.A(href="/", cls="link").render()
    assert tag == '<a href="/" class="link"></a>'


def test_atag_yes_attrs_text_children():
    tag = ft.A("Link here", href="/", cls="link").render()
    assert tag == '<a href="/" class="link">Link here</a>'


def test_divtag_yes_attrs_a_child():
    html = ft.Div(ft.A("Link here", href="/", cls="link")).render()
    assert html == '<div><a href="/" class="link">Link here</a></div>'


def test_divtag_yes_attrs_multiple_a_children():
    html = ft.Div(
        ft.A("Link here", href="/", cls="link"),
        ft.A("Another link", href="/", cls="timid"),
    ).render()
    assert (
        html
        == '<div><a href="/" class="link">Link here</a><a href="/" class="timid">Another link</a></div>'
    )


def test_divtag_yes_attrs_nested_children():
    html = ft.Div(
        ft.P(
            "Links are here",
            ft.A("Link here", href="/", cls="link"),
            ft.A("Another link", href="/", cls="timid"),
        )
    ).render()
    assert (
        html
        == '<div><p>Links are here<a href="/" class="link">Link here</a><a href="/" class="timid">Another link</a></p></div>'
    )


def test_tag_types():
    assert issubclass(ft.A, ft.FTag)
    assert issubclass(ft.Div, ft.FTag)
    assert issubclass(ft.P, ft.FTag)


def test_subclassing():
    class AwesomeP(ft.P):
        def render(self) -> str:
            return f"<p{self.attrs}>AWESOME {self.children}!</p>"

    assert AwesomeP("library").render() == "<p>AWESOME library!</p>"


def test_subclassing_nested():
    class AwesomeP(ft.P):
        def render(self) -> str:
            return f"<p{self.attrs}>AWESOME {self.children}!</p>"

    html = ft.Div(AwesomeP("library")).render()
    assert html == "<div><p>AWESOME library!</p></div>"


def test_text_child_with_sibling_elements():
    html = ft.P("This is a", ft.Strong("cut off"), "sentence").render()
    assert html == "<p>This is a<strong>cut off</strong>sentence</p>"

==> fastapi_tags-0.3.0.tar.gz: fastapi_tags-0.3.0/tests/test_tags.py <==
import fastapi_tags as tg


def test_atag_no_attrs_no_children():
    assert tg.A().render() == "<a></a>"


def test_atag_yes_attrs_no_children():
    tag = tg.A(href="/", cls="link").render()
    assert tag == '<a href="/" class="link"></a>'


def test_atag_yes_attrs_text_children():
    tag = tg.A("Link here", href="/", cls="link").render()
    assert tag == '<a href="/" class="link">Link here</a>'


def test_divtag_yes_attrs_a_child():
    html = tg.Div(tg.A("Link here", href="/", cls="link")).render()
    assert html == '<div><a href="/" class="link">Link here</a></div>'


def test_divtag_yes_attrs_multiple_a_children():
    html = tg.Div(
        tg.A("Link here", href="/", cls="link"),
        tg.A("Another link", href="/", cls="timid"),
    ).render()
    assert (
        html
        == '<div><a href="/" class="link">Link here</a><a href="/" class="timid">Another link</a></div>'
    )


def test_divtag_yes_attrs_nested_children():
    html = tg.Div(
        tg.P(
            "Links are here",
            tg.A("Link here", href="/", cls="link"),
            tg.A("Another link", href="/", cls="timid"),
        )
    ).render()
    assert (
        html
        == '<div><p>Links are here<a href="/" class="link">Link here</a><a href="/" class="timid">Another link</a></p></div>'
    )


def test_name_types():
    assert issubclass(tg.A, tg.Tag)
    assert issubclass(tg.Div, tg.Tag)
    assert issubclass(tg.P, tg.Tag)


def test_subclassing():
    class AwesomeP(tg.P):
        def render(self) -> str:
            return f"<p{self.attrs}>AWESOME {self.children}!</p>"

    assert AwesomeP("library").render() == "<p>AWESOME library!</p>"


def test_subclassing_nested():
    class AwesomeP(tg.P):
        def render(self) -> str:
            return f"<p{self.attrs}>AWESOME {self.children}!</p>"

    html = tg.Div(AwesomeP("library")).render()
    assert html == "<div><p>AWESOME library!</p></div>"


def test_text_child_with_sibling_elements():
    html = tg.P("This is a", tg.Strong("cut off"), "sentence").render()
    assert html == "<p>This is a<strong>cut off</strong>sentence</p>"
